amba-event-stream
=========

  ![PyPI](https://img.shields.io/pypi/v/amba-event-stream)

amba analytics event stream python package that connects to kafka to produce/connect or process events.

Installation
------------

`pip install amba-event-stream`
